<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<defaultcodec>windows-1251</defaultcodec>
<context>
    <name>QColorDialog</name>
    <message>
        <location filename="../src/gui/dialogs/qcolordialog.cpp" line="1253"/>
        <source>Hu&amp;e:</source>
        <translation>&amp;Tono:</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qcolordialog.cpp" line="1254"/>
        <source>&amp;Sat:</source>
        <translation>&amp;Saturación:</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qcolordialog.cpp" line="1255"/>
        <source>&amp;Val:</source>
        <translation>&amp;Valor:</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qcolordialog.cpp" line="1256"/>
        <source>&amp;Red:</source>
        <translation>&amp;Rojo:</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qcolordialog.cpp" line="1257"/>
        <source>&amp;Green:</source>
        <translation>&amp;Verde:</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qcolordialog.cpp" line="1258"/>
        <source>Bl&amp;ue:</source>
        <translation>Az&amp;ul:</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qcolordialog.cpp" line="1259"/>
        <source>A&amp;lpha channel:</source>
        <translation>Canal a&amp;lfa:</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qcolordialog.cpp" line="1360"/>
        <source>Select Color</source>
        <translation>Seleccionar color</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qcolordialog.cpp" line="1497"/>
        <source>&amp;Basic colors</source>
        <translation>Colores &amp;básicos</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qcolordialog.cpp" line="1498"/>
        <source>&amp;Custom colors</source>
        <translation>&amp;Colores personalizados</translation>
    </message>
    <message>
        <source>&amp;Define Custom Colors &gt;&gt;</source>
        <translation type="obsolete">&amp;Definir colores personalizados &gt;&gt;</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">Aceptar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Cancelar</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qcolordialog.cpp" line="1499"/>
        <source>&amp;Add to Custom Colors</source>
        <translation>&amp;Añadir a los colores personalizados</translation>
    </message>
    <message>
        <source>Select color</source>
        <translation type="obsolete">Seleccionar color</translation>
    </message>
</context>
<context>
    <name>QDialogButtonBox</name>
    <message>
        <location filename="../src/gui/dialogs/qmessagebox.cpp" line="1866"/>
        <location filename="../src/gui/dialogs/qmessagebox.cpp" line="2330"/>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="561"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="564"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="564"/>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="567"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="570"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="570"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="573"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="573"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="576"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="579"/>
        <source>Reset</source>
        <translation>Reinicializar</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="582"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="586"/>
        <source>Don&apos;t Save</source>
        <translation>No guardar</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="590"/>
        <source>Discard</source>
        <translation>Descartar</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="593"/>
        <source>&amp;Yes</source>
        <translation>&amp;Sí</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="596"/>
        <source>Yes to &amp;All</source>
        <translation>Sí a &amp;todo</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="599"/>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="602"/>
        <source>N&amp;o to All</source>
        <translation>N&amp;o a todo</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="605"/>
        <source>Save All</source>
        <translation>Guardar todo</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="608"/>
        <source>Abort</source>
        <translation>Interrumpir</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="611"/>
        <source>Retry</source>
        <translation>Reintentar</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="614"/>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="617"/>
        <source>Restore Defaults</source>
        <translation>Restaurar los valores predeterminados</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="588"/>
        <source>Close without Saving</source>
        <translation>Cerrar sin guardar</translation>
    </message>
    <message>
        <location filename="../src/gui/widgets/qdialogbuttonbox.cpp" line="561"/>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
</context>
<context>
    <name>QFontDatabase</name>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="90"/>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1266"/>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="93"/>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="105"/>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1254"/>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="96"/>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1256"/>
        <source>Demi Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="99"/>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="117"/>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1252"/>
        <source>Black</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="107"/>
        <source>Demi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="113"/>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1258"/>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="254"/>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1261"/>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="257"/>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1263"/>
        <source>Oblique</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1968"/>
        <source>Any</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1971"/>
        <source>Latin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1974"/>
        <source>Greek</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1977"/>
        <source>Cyrillic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1980"/>
        <source>Armenian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1983"/>
        <source>Hebrew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1986"/>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1989"/>
        <source>Syriac</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1992"/>
        <source>Thaana</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1995"/>
        <source>Devanagari</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="1998"/>
        <source>Bengali</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2001"/>
        <source>Gurmukhi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2004"/>
        <source>Gujarati</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2007"/>
        <source>Oriya</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2010"/>
        <source>Tamil</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2013"/>
        <source>Telugu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2016"/>
        <source>Kannada</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2019"/>
        <source>Malayalam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2022"/>
        <source>Sinhala</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2025"/>
        <source>Thai</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2028"/>
        <source>Lao</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2031"/>
        <source>Tibetan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2034"/>
        <source>Myanmar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2037"/>
        <source>Georgian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2040"/>
        <source>Khmer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2043"/>
        <source>Simplified Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2046"/>
        <source>Traditional Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2049"/>
        <source>Japanese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2052"/>
        <source>Korean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2055"/>
        <source>Vietnamese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2058"/>
        <source>Symbol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2061"/>
        <source>Ogham</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/text/qfontdatabase.cpp" line="2064"/>
        <source>Runic</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QFontDialog</name>
    <message>
        <location filename="../src/gui/dialogs/qfontdialog.cpp" line="772"/>
        <source>&amp;Font</source>
        <translation>&amp;Tipo de letra</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qfontdialog.cpp" line="773"/>
        <source>Font st&amp;yle</source>
        <translation>&amp;Estilo del tipo de letra</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qfontdialog.cpp" line="774"/>
        <source>&amp;Size</source>
        <translation>&amp;Tamaño</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qfontdialog.cpp" line="775"/>
        <source>Effects</source>
        <translation>Efectos</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qfontdialog.cpp" line="776"/>
        <source>Stri&amp;keout</source>
        <translation>&amp;Tachado</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qfontdialog.cpp" line="777"/>
        <source>&amp;Underline</source>
        <translation>S&amp;ubrayado</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qfontdialog.cpp" line="778"/>
        <source>Sample</source>
        <translation>Muestra</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qfontdialog.cpp" line="779"/>
        <source>Wr&amp;iting System</source>
        <translation>Sistema de escr&amp;itura</translation>
    </message>
    <message>
        <location filename="../src/gui/dialogs/qfontdialog.cpp" line="175"/>
        <location filename="../src/gui/dialogs/qfontdialog.cpp" line="422"/>
        <source>Select Font</source>
        <translation>Seleccionar un tipo de letra</translation>
    </message>
</context>
<context>
    <name>Details</name>
    <message>
        <location filename="../../ui/details.ui" line="23"/>
        <source>Information for station</source>
        <translation>Información para la estación</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>This is the first launch of the program.
By default, only Moscow map is available.
Want to download more cities?</source>
        <translation>Este es el primer lanzamiento del programa.
Por defecto, sólo está disponible el mapa de Moscú.
¿Quieres descargar más ciudades?</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="148"/>
        <location filename="../../ui/mainwindow.ui" line="565"/>
        <source>Find</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="211"/>
        <source>Waiting time</source>
        <translation>El tiempo de espera</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="253"/>
        <source>Time to station:</source>
        <translation>Tiempo a la estación:</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="299"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="426"/>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="440"/>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="444"/>
        <source>Language</source>
        <translation>Lengua</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="459"/>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="470"/>
        <source>&amp;Info</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="478"/>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="568"/>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="583"/>
        <source>Clear</source>
        <translation>Claro</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="586"/>
        <source>Alt+Del</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="598"/>
        <source>Save As...</source>
        <translation>Guardar como...</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="601"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="613"/>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="616"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="625"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="628"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="648"/>
        <location filename="../../ui/mainwindow.ui" line="651"/>
        <source>Zoom in</source>
        <translation>Zoom +</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="663"/>
        <location filename="../../ui/mainwindow.ui" line="666"/>
        <source>Zoom out</source>
        <translation>Zoom -</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="680"/>
        <source>Save scale</source>
        <translation>Guardar escala</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="692"/>
        <source>Preference</source>
        <translation>Preferencia</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="695"/>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="709"/>
        <source>Show time</source>
        <translation>Mostrar el tiempo</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="720"/>
        <source>Show hint</source>
        <translation>Mostrar pista</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="757"/>
        <source>Save position</source>
        <translation>Guardar la posición</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="762"/>
        <source>Add maps...</source>
        <translation>Agregue mapas...</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="774"/>
        <source>Screen mode</source>
        <translation>El modo de pantalla</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="777"/>
        <source>Alt+Return</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="749"/>
        <source>Transliterate</source>
        <translation>Transcribir</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="397"/>
        <source>Routes</source>
        <translation>Rutas</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="729"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="738"/>
        <source>Zoom to fit</source>
        <translation>Zoom para ajustar</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="465"/>
        <source>Open file</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="465"/>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Save file</source>
        <translation type="obsolete">Guardar archivo</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="obsolete">Acerca de</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="679"/>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="268"/>
        <location filename="../../src/mainwindow.cpp" line="679"/>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="270"/>
        <source>Start</source>
        <translation>Comienzo</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="271"/>
        <source>Finish</source>
        <translation>Terminar</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="273"/>
        <source>Default start</source>
        <translation>Comenzo defecto</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="685"/>
        <source>Categories</source>
        <translation>Categorías</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="918"/>
        <source>Add maps</source>
        <translation>Agregue mapas</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="918"/>
        <source>1. Wait until loaded site...
2. Select map
3. Save file map here:</source>
        <translation>1. Espere hasta que el sitio está cargado...
2. Seleccione un mapa
3. Guardar un archivo de mapa aquí:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../../ui/settings.ui" line="26"/>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="94"/>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="133"/>
        <source>Custom font and style for station</source>
        <translation>Fuente personalizada para la estación</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="146"/>
        <source>Font and style for station name</source>
        <translation>Fuente y el estilo de nombre de la estación</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="212"/>
        <source>Font...</source>
        <translation>Fuente...</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="219"/>
        <source>Back color</source>
        <translation>Color de fondo</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="577"/>
        <source>Simple graphics for transfers*</source>
        <translation>Gráficos simples para las transferencias*</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="49"/>
        <source>Color...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="257"/>
        <source>Shadow</source>
        <translation>Sombra</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="292"/>
        <source>Upper case</source>
        <translation>Letras mayúsculas</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="299"/>
        <source>Word wrap*</source>
        <translation>ajuste de línea*</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="454"/>
        <source>Full screen mode*</source>
        <translation>Modo de pantalla completa*</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="337"/>
        <source>Transparency when drawing the route</source>
        <translation>Transparencia de la ruta</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="444"/>
        <source>Show a scrollbar</source>
        <translation>Mostrar una barra de desplazamiento</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="403"/>
        <source>Map back color</source>
        <translation>Mapa del color de fondo</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="410"/>
        <source>Scale of interface</source>
        <translation>Escala de la interfaz</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="497"/>
        <source>Performance</source>
        <translation>Rendimiento</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="524"/>
        <source>Cache graphics to raster</source>
        <translation>Gráficos de caché de mapa de bits</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="534"/>
        <source>Show time to the stations</source>
        <translation>Mostrar el tiempo a las estaciones</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="544"/>
        <source>Show the background for map</source>
        <translation>Mostrar el fondo para el mapa</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="554"/>
        <source>Antialiasing filter</source>
        <translation>Antialiasing filtro</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="564"/>
        <source>Fast scrolling (without antialiasing)</source>
        <translation>Desplazamiento rápido (sin antialiasing) </translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="616"/>
        <source>Other</source>
        <translation>Otro</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="646"/>
        <source>Cache</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="667"/>
        <source>Clean the cache on exit</source>
        <translation>Limpiar la caché de salida</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="725"/>
        <source>Empty Now</source>
        <translation>Vaciar ahora</translation>
    </message>
</context>
<context>
    <name>TMapView</name>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="381"/>
        <source>Day</source>
        <translation>Día</translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="381"/>
        <source>Night</source>
        <translation>Noche</translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="381"/>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="381"/>
        <source>Rush Hour</source>
        <translation>Hora punta</translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="501"/>
        <source>Cannot open file mapping:
%1</source>
        <translation>No se puede abrir archivo de asignación:
%1</translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1662"/>
        <source>line</source>
        <translation>línea</translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1670"/>
        <source>Begin station:</source>
        <translation>Comenzar la estación:</translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1682"/>
        <source>Go to station:</source>
        <translation>Ir a la estación:</translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1684"/>
        <source>Transfer to station:</source>
        <translation>Traslado a la estación:</translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1689"/>
        <source>Final station:</source>
        <translation>Estación final:</translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1696"/>
        <location filename="../../src/mapview/mapview.cpp" line="1701"/>
        <source>st.</source>
        <translation>est.</translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1704"/>
        <source>Travel time</source>
        <translation>Viaje en el tiempo</translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1706"/>
        <source>min.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1707"/>
        <source>transf.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1947"/>
        <source>Save file</source>
        <translation>Guardar archivo</translation>
    </message>
</context>
<context>
    <name>UnZip</name>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1138"/>
        <source>ZIP operation completed successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1139"/>
        <source>Failed to initialize or load zlib library.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1140"/>
        <source>zlib library error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1141"/>
        <source>Unable to create or open file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1142"/>
        <source>Partially corrupted archive. Some files might be extracted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1143"/>
        <source>Corrupted archive.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1144"/>
        <source>Wrong password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1145"/>
        <source>No archive has been created yet.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1146"/>
        <source>File or directory does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1147"/>
        <source>File read error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1148"/>
        <source>File write error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1149"/>
        <source>File seek error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1150"/>
        <source>Unable to create a directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1151"/>
        <source>Invalid device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1152"/>
        <source>Invalid or incompatible zip archive.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1153"/>
        <source>Inconsistent headers. Archive might be corrupted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1157"/>
        <source>Unknown error.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>About</name>
    <message>
        <location filename="../../src/about.h" line="27"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="63"/>
        <source>Unknown author</source>
        <translation>Autor desconocido</translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="64"/>
        <source>transit system map</source>
        <translation>mapa del sistema de tránsito</translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="64"/>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="64"/>
        <source>Author of map file format</source>
        <translation>Autor de formato de archivo de mapa</translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="65"/>
        <source>About current map file</source>
        <translation>Acerca del archivo de mapa actual</translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="65"/>
        <source>This program uses</source>
        <translation>Este programa utiliza</translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="66"/>
        <source>This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.</source>
        <translation>Este programa se distribuye con la esperanza de que sea útil, pero SIN NINGUNA GARANTÍA, incluso sin la garantía implícita de O IDONEIDAD PARA UN PROPÓSITO PARTICULAR.  Ver el GNU General Public License para más detalles.</translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="69"/>
        <source>Author of translation: Gusak Leonid</source>
        <translation>Autor de la traducción: Gusak Leonid</translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="90"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>Zip</name>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1205"/>
        <source>ZIP operation completed successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1206"/>
        <source>Failed to initialize or load zlib library.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1207"/>
        <source>zlib library error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1208"/>
        <source>Unable to create or open file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1209"/>
        <source>No archive has been created yet.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1210"/>
        <source>File or directory does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1211"/>
        <source>File read error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1212"/>
        <source>File write error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1213"/>
        <source>File seek error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1217"/>
        <source>Unknown error.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
